@@ -6,7 +6,10 @@ use base qw/Net::PulseMeter::Sensor::Timeline/;
 
 sub aggregate_event {
     my ($self, $key, $data) = @_;
-    $self->r->hincrby($key, $_, $data->{$_}) for (keys(%$data));
+    for (keys(%$data)) {
+        $self->r->hincrby($key, $_, $data->{$_}); 
+        $self->r->hincrby($key, "total", $data->{$_}); 
+    }
 }
 
 1;
